@@ -1,4 +1,6 @@
 import json
+import os
+import shutil
 from sys import executable
 import unittest
 
@@ -10,6 +12,8 @@ from pyutils.autoupgrade import AutoUpgrade
 class TestAutoupgrade(unittest.TestCase):
     def test_autoupgrade(self):
         # TODO:there should create an isolated env for testing.
+        if os.path.exists('pyutils_basstal.egg-info'):
+            shutil.rmtree('pyutils_basstal.egg-info')
         executor = Executor(True)
         result = executor.execute_straight(executable, ["-m", "pip", "uninstall", "pyutils_basstal", "--yes"])
         self.assertEqual(result.code, 0)
@@ -17,7 +21,8 @@ class TestAutoupgrade(unittest.TestCase):
         self.assertEqual(result.code, 0)
         autoupgrade = AutoUpgrade("pyutils_basstal", verbose=True)
         # TODO: there may timeout.
-        autoupgrade.upgrade_if_needed(False, True)
+        upgrade_needed = autoupgrade.upgrade_if_needed(False, True)
+        self.assertTrue(upgrade_needed)
         # NOTE: py is specified as python3 executable
         result = executor.execute_straight(executable, ['-m', "pip", "list", "-u", "--format=json"])
         result = json.loads(result.out_str)
